Storage
=======

Storage locations and backend helpers for local paths, supported remote storage
providers, and placeholder backends for unsupported schemes.

.. autosummary::
   :toctree: generated

   etlplus.storage
   etlplus.storage.azure_blob
   etlplus.storage.local
   etlplus.storage.s3
   etlplus.storage.stub
